/****************************************************************************
** Meta object code from reading C++ file 'calendardecoration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.08.0/src/agenda/calendardecoration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendardecoration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::CalendarDecoration::Element::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::CalendarDecoration::Element",
        "gotNewPixmap",
        "",
        "QPixmap",
        "gotNewShortText",
        "gotNewLongText",
        "gotNewExtensiveText",
        "gotNewUrl",
        "QUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'gotNewPixmap'
        QtMocHelpers::SignalData<void(const QPixmap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'gotNewShortText'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'gotNewLongText'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'gotNewExtensiveText'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'gotNewUrl'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Element, qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::CalendarDecoration::Element::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>.metaTypes,
    nullptr
} };

void EventViews::CalendarDecoration::Element::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Element *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->gotNewPixmap((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1]))); break;
        case 1: _t->gotNewShortText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->gotNewLongText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->gotNewExtensiveText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->gotNewUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Element::*)(const QPixmap & )>(_a, &Element::gotNewPixmap, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)(const QString & )>(_a, &Element::gotNewShortText, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)(const QString & )>(_a, &Element::gotNewLongText, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)(const QString & )>(_a, &Element::gotNewExtensiveText, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Element::*)(const QUrl & )>(_a, &Element::gotNewUrl, 4))
            return;
    }
}

const QMetaObject *EventViews::CalendarDecoration::Element::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::Element::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration7ElementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::Element::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void EventViews::CalendarDecoration::Element::gotNewPixmap(const QPixmap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EventViews::CalendarDecoration::Element::gotNewShortText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EventViews::CalendarDecoration::Element::gotNewLongText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EventViews::CalendarDecoration::Element::gotNewExtensiveText(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EventViews::CalendarDecoration::Element::gotNewUrl(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::CalendarDecoration::StoredElement::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::CalendarDecoration::StoredElement"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StoredElement, qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::CalendarDecoration::StoredElement::staticMetaObject = { {
    QMetaObject::SuperData::link<Element::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>.metaTypes,
    nullptr
} };

void EventViews::CalendarDecoration::StoredElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StoredElement *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EventViews::CalendarDecoration::StoredElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::StoredElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration13StoredElementE_t>.strings))
        return static_cast<void*>(this);
    return Element::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::StoredElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Element::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::CalendarDecoration::Decoration::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::CalendarDecoration::Decoration"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Decoration, qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::CalendarDecoration::Decoration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>.metaTypes,
    nullptr
} };

void EventViews::CalendarDecoration::Decoration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Decoration *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EventViews::CalendarDecoration::Decoration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::CalendarDecoration::Decoration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews18CalendarDecoration10DecorationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EventViews::CalendarDecoration::Decoration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
