/****************************************************************************
** Meta object code from reading C++ file 'multiagendaview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.08.0/src/multiagenda/multiagendaview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multiagendaview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::MultiAgendaView::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::MultiAgendaView",
        "showNewEventPopupSignal",
        "",
        "showIncidencePopupSignal",
        "Akonadi::CollectionCalendar::Ptr",
        "Akonadi::Item",
        "activeCalendarChanged",
        "customCollectionsChanged",
        "EventViews::ConfigDialogInterface*",
        "dlg",
        "showDates",
        "start",
        "end",
        "preferredMonth",
        "showIncidences",
        "Akonadi::Item::List",
        "incidenceList",
        "date",
        "updateView",
        "updateConfig",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "collectionSelectionChanged",
        "slotSelectionChanged",
        "slotClearTimeSpanSelection",
        "resizeSplitters",
        "setupScrollBar",
        "zoomView",
        "delta",
        "QPoint",
        "pos",
        "Qt::Orientation",
        "ori",
        "slotResizeScrollView",
        "recreateViews",
        "forceRecreateViews"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showNewEventPopupSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showIncidencePopupSignal'
        QtMocHelpers::SignalData<void(const Akonadi::CollectionCalendar::Ptr &, const Akonadi::Item &, const QDate &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'activeCalendarChanged'
        QtMocHelpers::SignalData<void(const Akonadi::CollectionCalendar::Ptr &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'customCollectionsChanged'
        QtMocHelpers::SlotData<void(EventViews::ConfigDialogInterface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 11 }, { QMetaType::QDate, 12 }, { QMetaType::QDate, 13 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 11 }, { QMetaType::QDate, 12 },
        }}),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QDate, 17 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'collectionSelectionChanged'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearTimeSpanSelection'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resizeSplitters'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setupScrollBar'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomView'
        QtMocHelpers::SlotData<void(const int, QPoint, const Qt::Orientation)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { 0x80000000 | 30, 31 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'slotResizeScrollView'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'recreateViews'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'forceRecreateViews'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultiAgendaView, qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::MultiAgendaView::staticMetaObject = { {
    QMetaObject::SuperData::link<EventView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>.metaTypes,
    nullptr
} };

void EventViews::MultiAgendaView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiAgendaView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showNewEventPopupSignal(); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 2: _t->activeCalendarChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1]))); break;
        case 3: _t->customCollectionsChanged((*reinterpret_cast<std::add_pointer_t<EventViews::ConfigDialogInterface*>>(_a[1]))); break;
        case 4: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 5: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 6: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 7: _t->updateView(); break;
        case 8: _t->updateConfig(); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 10: _t->collectionSelectionChanged(); break;
        case 11: _t->slotSelectionChanged(); break;
        case 12: _t->slotClearTimeSpanSelection(); break;
        case 13: _t->resizeSplitters(); break;
        case 14: _t->setupScrollBar(); break;
        case 15: _t->zoomView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[3]))); break;
        case 16: _t->slotResizeScrollView(); break;
        case 17: _t->recreateViews(); break;
        case 18: _t->forceRecreateViews(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultiAgendaView::*)()>(_a, &MultiAgendaView::showNewEventPopupSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiAgendaView::*)(const Akonadi::CollectionCalendar::Ptr & , const Akonadi::Item & , const QDate & )>(_a, &MultiAgendaView::showIncidencePopupSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiAgendaView::*)(const Akonadi::CollectionCalendar::Ptr & )>(_a, &MultiAgendaView::activeCalendarChanged, 2))
            return;
    }
}

const QMetaObject *EventViews::MultiAgendaView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::MultiAgendaView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15MultiAgendaViewE_t>.strings))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::MultiAgendaView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void EventViews::MultiAgendaView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::MultiAgendaView::showIncidencePopupSignal(const Akonadi::CollectionCalendar::Ptr & _t1, const Akonadi::Item & _t2, const QDate & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void EventViews::MultiAgendaView::activeCalendarChanged(const Akonadi::CollectionCalendar::Ptr & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
