/****************************************************************************
** Meta object code from reading C++ file 'agendaview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.08.0/src/agenda/agendaview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'agendaview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews14EventIndicatorE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::EventIndicator::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews14EventIndicatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::EventIndicator"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EventIndicator, qt_meta_tag_ZN10EventViews14EventIndicatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::EventIndicator::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews14EventIndicatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews14EventIndicatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews14EventIndicatorE_t>.metaTypes,
    nullptr
} };

void EventViews::EventIndicator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EventIndicator *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EventViews::EventIndicator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::EventIndicator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews14EventIndicatorE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EventViews::EventIndicator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN10EventViews10AgendaViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::AgendaView::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews10AgendaViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::AgendaView",
        "showNewEventPopupSignal",
        "",
        "showIncidencePopupSignal",
        "Akonadi::CollectionCalendar::Ptr",
        "Akonadi::Item",
        "zoomViewHorizontally",
        "timeSpanSelectionChanged",
        "updateView",
        "updateConfig",
        "slotIncidencesDropped",
        "KCalendarCore::Incidence::List",
        "incidences",
        "QPoint",
        "slotUrlsDropped",
        "QList<QUrl>",
        "urls",
        "startDrag",
        "KCalendarCore::Incidence::Ptr",
        "updateEventIndicatorTop",
        "newY",
        "updateEventIndicatorBottom",
        "newTimeSpanSelected",
        "start",
        "end",
        "newTimeSpanSelectedAllDay",
        "updateEventIndicators",
        "scheduleUpdateEventIndicators",
        "alignAgendas"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showNewEventPopupSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showIncidencePopupSignal'
        QtMocHelpers::SignalData<void(const Akonadi::CollectionCalendar::Ptr &, const Akonadi::Item &, const QDate &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'zoomViewHorizontally'
        QtMocHelpers::SignalData<void(const QDate &, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'timeSpanSelectionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotIncidencesDropped'
        QtMocHelpers::SlotData<void(const KCalendarCore::Incidence::List &, const QPoint &, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotUrlsDropped'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QPoint &, bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 13, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'startDrag'
        QtMocHelpers::SlotData<void(const KCalendarCore::Incidence::Ptr &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'updateEventIndicatorTop'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'updateEventIndicatorBottom'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'newTimeSpanSelected'
        QtMocHelpers::SlotData<void(const QPoint &, const QPoint &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 23 }, { 0x80000000 | 13, 24 },
        }}),
        // Slot 'newTimeSpanSelectedAllDay'
        QtMocHelpers::SlotData<void(const QPoint &, const QPoint &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 23 }, { 0x80000000 | 13, 24 },
        }}),
        // Slot 'updateEventIndicators'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'scheduleUpdateEventIndicators'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'alignAgendas'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AgendaView, qt_meta_tag_ZN10EventViews10AgendaViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::AgendaView::staticMetaObject = { {
    QMetaObject::SuperData::link<EventView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews10AgendaViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews10AgendaViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews10AgendaViewE_t>.metaTypes,
    nullptr
} };

void EventViews::AgendaView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AgendaView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showNewEventPopupSignal(); break;
        case 1: _t->showIncidencePopupSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::CollectionCalendar::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 2: _t->zoomViewHorizontally((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->timeSpanSelectionChanged(); break;
        case 4: _t->updateView(); break;
        case 5: _t->updateConfig(); break;
        case 6: _t->slotIncidencesDropped((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->slotUrlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->startDrag((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1]))); break;
        case 9: _t->updateEventIndicatorTop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->updateEventIndicatorBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->newTimeSpanSelected((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 12: _t->newTimeSpanSelectedAllDay((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 13: _t->updateEventIndicators(); break;
        case 14: _t->scheduleUpdateEventIndicators(); break;
        case 15: _t->alignAgendas(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AgendaView::*)()>(_a, &AgendaView::showNewEventPopupSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgendaView::*)(const Akonadi::CollectionCalendar::Ptr & , const Akonadi::Item & , const QDate & )>(_a, &AgendaView::showIncidencePopupSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgendaView::*)(const QDate & , int )>(_a, &AgendaView::zoomViewHorizontally, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AgendaView::*)()>(_a, &AgendaView::timeSpanSelectionChanged, 3))
            return;
    }
}

const QMetaObject *EventViews::AgendaView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::AgendaView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews10AgendaViewE_t>.strings))
        return static_cast<void*>(this);
    return EventView::qt_metacast(_clname);
}

int EventViews::AgendaView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EventView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void EventViews::AgendaView::showNewEventPopupSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EventViews::AgendaView::showIncidencePopupSignal(const Akonadi::CollectionCalendar::Ptr & _t1, const Akonadi::Item & _t2, const QDate & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void EventViews::AgendaView::zoomViewHorizontally(const QDate & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void EventViews::AgendaView::timeSpanSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
