/****************************************************************************
** Meta object code from reading C++ file 'journalframe.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../eventviews-26.08.0/src/journal/journalframe.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journalframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10EventViews12JournalFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::JournalFrame::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews12JournalFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::JournalFrame",
        "printJournalSignal",
        "",
        "KCalendarCore::Journal::Ptr",
        "deleteIncidence",
        "Akonadi::Item",
        "editIncidence",
        "incidenceSelected",
        "setDirty",
        "deleteItem",
        "editItem",
        "printJournal",
        "printPreviewJournal",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "setDate",
        "date"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'printJournalSignal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Journal::Ptr &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'deleteIncidence'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'editIncidence'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'incidenceSelected'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Slot 'setDirty'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'deleteItem'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'editItem'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'printJournal'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'printPreviewJournal'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setDate'
        QtMocHelpers::SlotData<void(QDate)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JournalFrame, qt_meta_tag_ZN10EventViews12JournalFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::JournalFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews12JournalFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews12JournalFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews12JournalFrameE_t>.metaTypes,
    nullptr
} };

void EventViews::JournalFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JournalFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->printJournalSignal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Journal::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 2: _t->editIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 3: _t->incidenceSelected((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 4: _t->setDirty(); break;
        case 5: _t->deleteItem(); break;
        case 6: _t->editItem(); break;
        case 7: _t->printJournal(); break;
        case 8: _t->printPreviewJournal(); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 10: _t->setDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Journal::Ptr >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JournalFrame::*)(const KCalendarCore::Journal::Ptr & , bool )>(_a, &JournalFrame::printJournalSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalFrame::*)(const Akonadi::Item & )>(_a, &JournalFrame::deleteIncidence, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalFrame::*)(const Akonadi::Item & )>(_a, &JournalFrame::editIncidence, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalFrame::*)(const Akonadi::Item & , const QDate & )>(_a, &JournalFrame::incidenceSelected, 3))
            return;
    }
}

const QMetaObject *EventViews::JournalFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::JournalFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews12JournalFrameE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int EventViews::JournalFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void EventViews::JournalFrame::printJournalSignal(const KCalendarCore::Journal::Ptr & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void EventViews::JournalFrame::deleteIncidence(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EventViews::JournalFrame::editIncidence(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EventViews::JournalFrame::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN10EventViews15JournalDateViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EventViews::JournalDateView::qt_create_metaobjectdata<qt_meta_tag_ZN10EventViews15JournalDateViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EventViews::JournalDateView",
        "setIncidenceChangerSignal",
        "",
        "Akonadi::IncidenceChanger*",
        "setDateSignal",
        "flushEntries",
        "editIncidence",
        "Akonadi::Item",
        "deleteIncidence",
        "newJournal",
        "incidenceSelected",
        "printJournal",
        "KCalendarCore::Journal::Ptr",
        "emitNewJournal",
        "setIncidenceChanger",
        "changer",
        "journalEdited",
        "journalDeleted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setIncidenceChangerSignal'
        QtMocHelpers::SignalData<void(Akonadi::IncidenceChanger *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'setDateSignal'
        QtMocHelpers::SignalData<void(const QDate &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'flushEntries'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editIncidence'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'deleteIncidence'
        QtMocHelpers::SignalData<void(const Akonadi::Item &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'newJournal'
        QtMocHelpers::SignalData<void(const QDate &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 2 },
        }}),
        // Signal 'incidenceSelected'
        QtMocHelpers::SignalData<void(const Akonadi::Item &, const QDate &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 }, { QMetaType::QDate, 2 },
        }}),
        // Signal 'printJournal'
        QtMocHelpers::SignalData<void(const KCalendarCore::Journal::Ptr &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'emitNewJournal'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 15 },
        }}),
        // Slot 'journalEdited'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'journalDeleted'
        QtMocHelpers::SlotData<void(const Akonadi::Item &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JournalDateView, qt_meta_tag_ZN10EventViews15JournalDateViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EventViews::JournalDateView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15JournalDateViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15JournalDateViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10EventViews15JournalDateViewE_t>.metaTypes,
    nullptr
} };

void EventViews::JournalDateView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JournalDateView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setIncidenceChangerSignal((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 1: _t->setDateSignal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 2: _t->flushEntries(); break;
        case 3: _t->editIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 4: _t->deleteIncidence((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 5: _t->newJournal((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->incidenceSelected((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 7: _t->printJournal((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Journal::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->emitNewJournal(); break;
        case 9: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 10: _t->journalEdited((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        case 11: _t->journalDeleted((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Journal::Ptr >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(Akonadi::IncidenceChanger * )>(_a, &JournalDateView::setIncidenceChangerSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const QDate & )>(_a, &JournalDateView::setDateSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)()>(_a, &JournalDateView::flushEntries, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const Akonadi::Item & )>(_a, &JournalDateView::editIncidence, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const Akonadi::Item & )>(_a, &JournalDateView::deleteIncidence, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const QDate & )>(_a, &JournalDateView::newJournal, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const Akonadi::Item & , const QDate & )>(_a, &JournalDateView::incidenceSelected, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournalDateView::*)(const KCalendarCore::Journal::Ptr & , bool )>(_a, &JournalDateView::printJournal, 7))
            return;
    }
}

const QMetaObject *EventViews::JournalDateView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventViews::JournalDateView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10EventViews15JournalDateViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EventViews::JournalDateView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void EventViews::JournalDateView::setIncidenceChangerSignal(Akonadi::IncidenceChanger * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EventViews::JournalDateView::setDateSignal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EventViews::JournalDateView::flushEntries()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EventViews::JournalDateView::editIncidence(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EventViews::JournalDateView::deleteIncidence(const Akonadi::Item & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void EventViews::JournalDateView::newJournal(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EventViews::JournalDateView::incidenceSelected(const Akonadi::Item & _t1, const QDate & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void EventViews::JournalDateView::printJournal(const KCalendarCore::Journal::Ptr & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
